==> haskell-binary-conduit-1.3.1-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-HsKh96BeKzw44wRCzauEpq
key: binary-conduit-1.3.1-HsKh96BeKzw44wRCzauEpq
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: e3c8a54520f3cc6f6882158d3b7a23b2
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.3/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-HsKh96BeKzw44wRCzauEpq
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1-JmMdk65SNka3dWWZlerpD5
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-DxjxvF5SmAEKA1UNyS7pPE
key: binary-conduit-1.3.1-DxjxvF5SmAEKA1UNyS7pPE
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 3a745e2524defef5ed07e5227cec16be
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.4/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-DxjxvF5SmAEKA1UNyS7pPE
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    exceptions-0.10.0-HSEN1HsF9E42usfcjSNYsT
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
